@@ -1,14 +1,14 @@
 import datetime
 
 PYCKSON_ATTR = '__{cls}_pyckson'
-PYCKSON_TYPEINFO = '__{cls}_pyckson_typeinfo'
+PYCKSON_TYPEINFO = '__pyckson_typeinfo'
 PYCKSON_MODEL = '__{cls}_pyckson_model'
-PYCKSON_ENUM_OPTIONS = '__{cls}_pyckson_enum'
-PYCKSON_NAMERULE = '__{cls}_pyckson_namerule'
-PYCKSON_SERIALIZER = '__{cls}_pyckson_serializer'
-PYCKSON_PARSER = '__{cls}_pyckson_parser'
-PYCKSON_DATE_FORMATTER = '__{cls}_pyckson_date_formatter'
-PYCKSON_EXPLICIT_NULLS = '__{cls}_pyckson_explicit_nulls'
+PYCKSON_ENUM_OPTIONS = '__pyckson_enum'
+PYCKSON_NAMERULE = '__pyckson_namerule'
+PYCKSON_SERIALIZER = '__pyckson_serializer'
+PYCKSON_PARSER = '__pyckson_parser'
+PYCKSON_DATE_FORMATTER = '__pyckson_date_formatter'
+PYCKSON_EXPLICIT_NULLS = '__pyckson_explicit_nulls'
 PYCKSON_RULE_ATTR = '__{cls}_pyckson_rule_attr'
 BASIC_TYPES = [int, str, float]
 EXTRA_TYPES = [bool, bytes, datetime.time]
